@@ -65,11 +65,14 @@ class PDFDocument(object):
 
         """
         if draw_color is None:
-            draw_color = PDFColor('d')
+            draw_color = PDFColor()
+            draw_color._set_type('d')
         if fill_color is None:
-            fill_color = PDFColor('f')
+            fill_color = PDFColor()
+            fill_color._set_type('f')
         if text_color is None:
-            text_color = PDFColor('t')
+            text_color = PDFColor()
+            text_color._set_type('t')
 
         self.draw_color = draw_color
         self.fill_color = fill_color
@@ -345,12 +348,7 @@ class PDFDocument(object):
         format = PDFCellFormat(data, font=font)
         return format
 
-    def add_image(self, image=None, name=None, cursor=None, dpi=72):
-        if not cursor:
-            imagecursor = self.page.cursor
-        else:
-            imagecursor = cursor
-
+    def add_image(self, image=None, name=None):
         if isinstance(image, PDFImage):  # It's an image object
             myimage = self._get_image(image.name)
             if not myimage:
@@ -370,20 +368,35 @@ class PDFDocument(object):
                 if not myimage:  # New image
                     extension = os.path.splitext(image_string)[1]
                     if extension == '.png':
-                        myimage = PDFPNG(self.session, image_string, name,
-                                         imagecursor, dpi)
+                        myimage = PDFPNG(self.session, image_string, name)
                     elif extension == '.jpg':
-                        myimage = PDFJPG(self.session, image_string, name,
-                                         imagecursor)
+                        myimage = PDFJPG(self.session, image_string, name)
                     else:
                         raise Exception("Image format %s not supported" % extension)
                     self._register_new_image(myimage)
+
+        return myimage
+
+    def draw_image(self, image, cursor=None, width=None, height=None):
+        if isinstance(image, PDFImage):  # It's an image object
+            myimage = self._get_image(image.name)
+        else:
+            try:
+                myimage = self._get_image(image)
+            except:
+                raise Exception("%s is an invalid image. Add it first.")
+
+        if not cursor:
+            imagecursor = self.page.cursor
+        else:
+            imagecursor = cursor
+        myimage._set_cursor(imagecursor)
+        myimage._set_size(width, height)
         myimage._draw(self.page)
 
         # If a cursor was not specified, place at the end
         if not cursor:
             self.page.cursor = myimage.cursor
-        return myimage
 
     def set_background_image(self, image, dpi=72):
         margins = PDFMargin(0, 0, None, None)
